# FILE: present.tcl
#
# The [package present] command of the package "package".
#
# Usage:
# 	package present ?-exact? $package ?$minVersion? ?$maxVersion?
#
# The [package present] command is meant to be a compatible extended
# version of the [package present] command in the Tcl core.  
#
# It behaves the same as the [package present] command in the Tcl core,
# except that it uses [package satisfies] to compare the version number
# of available releases of $package against the $minVersion and
# $maxVersion arguments to determine whether a present package satisfies
# the requirement.
#

# If the core provides [package present] (Tcl 8.1 and later), Wrap and
# use that.

if {[package vsatisfies [package provide Tcl] 8.1]} {

proc ::package::present {args} {
  
    # Pass along to the core "package present" any $args which it
    # can handle.
    if {[string match -exact [lindex $args 0]]
	    || [llength $args] != 3} {
	eval [Wrap "::package:: present" ""]
    }

    # Okay, $args is [list $package $minVersion $maxVersion]
    set package [lindex $args 0]
    if {[string length [package provide $package]]} {
	set code [catch {uplevel 1 [list package require] $args} msg]
	return -code $code $msg
    }
    return -code error "package satisfying $args is not present"
}

} else {

# No core [package provide].

proc ::package::present {package args} {
  
    if {[string length [package provide $package]]} {
	set code [catch {
		uplevel 1 [list package require $package] $args
	} msg]
	return -code $code $msg
    }
    return -code error \
	    "package satisfying $package $args is not present"
}

}

